@@ -100,6 +100,7 @@ Out of the box implementation of the Construct without any override will set the
 * Enable server-side encryption for DynamoDB Table using AWS managed KMS Key
 * Creates a partition key called 'id' for DynamoDB Table
 * Retain the Table when deleting the CloudFormation stack
+* Enable continuous backups and point-in-time recovery
 
 ## Architecture
 
@@ -218,15 +219,11 @@ class IotToLambdaToDynamoDBProps:
         :summary:: The properties for the IotToLambdaToDynamoDB class.
         """
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(
-                **iot_topic_rule_props
-            )
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
